package cn.com.infosec.mobile.android;

import android.content.Context;
import android.content.SharedPreferences;
import android.os.Build;
import android.os.Environment;
import android.os.Build.VERSION;
import android.preference.PreferenceManager;
import android.support.annotation.NonNull;
import android.text.TextUtils;
import android.util.Base64;
import cn.com.infosec.mobile.android.algorithm.SM3;
import cn.com.infosec.mobile.android.algorithm.SM4;
import cn.com.infosec.mobile.android.log.JSONFormatter;
import cn.com.infosec.mobile.android.result.Result;
import cn.com.infosec.mobile.android.util.Util;
import cn.com.infosec.mobile.android.xlog.XLog;
import java.io.File;
import java.io.IOException;
import java.security.SecureRandom;
import java.util.Arrays;
import java.util.HashMap;
import java.util.Map;
import java.util.logging.FileHandler;
import java.util.logging.Level;
import java.util.logging.Logger;
import org.json.JSONException;
import org.json.JSONObject;

public class IMSAction {
   protected Context context;
   private Map<String, Object> cacheMap;
   private Result latestResult;

   public IMSAction(Context context) {
      IMSAction var10000 = this;
      super();
      this.context = context;
      HashMap var2;
      var2 = new HashMap.<init>();
      var10000.cacheMap = var2;
   }

   private String parseStringData(String base64Data) {
      return new String(Base64.decode(base64Data, 2));
   }

   private int parseIntData(String base64Data) {
      String var2;
      String var10000 = var2 = new String;
      var10000.<init>(Base64.decode(base64Data, 2));
      return TextUtils.isEmpty(var10000) ? 0 : Integer.parseInt(var2);
   }

   private long parseLongData(String base64Data) {
      String var2;
      String var10000 = var2 = new String;
      var10000.<init>(Base64.decode(base64Data, 2));
      return TextUtils.isEmpty(var10000) ? 0L : Long.parseLong(var2);
   }

   public Result getLatestResult() {
      return this.latestResult;
   }

   public void setLatestResult(Result latestResult) {
      this.latestResult = latestResult;
   }

   protected SharedPreferences getGlobalSP() {
      return PreferenceManager.getDefaultSharedPreferences(this.context);
   }

   protected SharedPreferences getUserSP(String userName) {
      return this.context.getSharedPreferences(userName, 0);
   }

   public int genP10Model() {
      return this.getGlobalSP().getInt("GEN_P10_BY_SERVER", 0);
   }

   protected Result checkResponseData(JSONObject responseData) {
      if (responseData != null && responseData.length() > 0) {
         Result var2;
         Result var10000 = var2 = new Result;
         var10000.<init>(responseData.getString("resultcode"));
         if (!TextUtils.equals("000000", var10000.getResultID())) {
            XLog.d("请求失败 resultID = " + var2.getResultID());
            if (responseData.has("resultmsg")) {
               var2.setResultDesc(responseData.getString("resultmsg"));
            }
         } else {
            XLog.d("请求成功");
         }

         return var2;
      } else {
         IMSSdk.mLogger.log(Level.SEVERE, "错误的响应数据", responseData);
         XLog.d("请求失败 responseData is null");
         return new Result("IE1048", "responseData is null");
      }
   }

   public boolean isCollaborative() {
      return 1 == this.getGlobalSP().getInt("IS_COLLABORATIVE", 0);
   }

   public boolean isCertAvailable() {
      return 1 == this.getGlobalSP().getInt("DIGITAL_CERT_AVAILABLE", 0);
   }

   public boolean isTokenAvailable() {
      return 1 == this.getGlobalSP().getInt("OTP_AVAILABLE", 0);
   }

   public boolean isPDFAvailable() {
      return 1 == this.getGlobalSP().getInt("PDF_AVAILABLE", 0);
   }

   public boolean isSignAvailable() {
      return 1 == this.getGlobalSP().getInt("DIGITAL_SIGN_AVAILABLE", 0);
   }

   public boolean isAppForceUpdate() {
      return 1 == this.getGlobalSP().getInt("APP_FORCE_UPDATE", 0);
   }

   public boolean isInfosecCollaborative() {
      return 1 == this.getGlobalSP().getInt("COLLABORATIVE_MODE", 0);
   }

   public boolean isServerPDFMode() {
      return 1 == this.getGlobalSP().getInt("PDF_SIGN_MODE", 0);
   }

   public boolean isPairedCert() {
      return 1 == this.getGlobalSP().getInt("IS_PAIRED_CERT", 0);
   }

   public int getSignAndTokenMode() {
      return this.getGlobalSP().getInt("SIGN_WITH_TOKEN_MODE", 0);
   }

   public int getSealerImageSize() {
      return this.getGlobalSP().getInt("NETSEAL_IMAGE_SIZE", 0);
   }

   public int getQRCodeExpireMillSeconds() {
      return this.getGlobalSP().getInt("QR_CODE_EXPIRE_MILLSECONDS", 0);
   }

   public int getSignCodeExpireMillSeconds() {
      return this.getGlobalSP().getInt("SIGN_CODE_EXPIRE_MILLSECONDS", 0);
   }

   public int getAPICheckType() {
      return this.getGlobalSP().getInt("API_CHECK_TYPE", 0);
   }

   public void clearAPICheckType() {
      SharedPreferences.Editor var10000 = this.getGlobalSP().edit();
      var10000.putInt("API_CHECK_TYPE", 0);
      var10000.apply();
   }

   public String getCertAlgorithm() {
      return this.getGlobalSP().getString("CERT_ALGORITHM", (String)null);
   }

   public int getCertKeyLength() {
      return this.getGlobalSP().getInt("CERT_KEY_LENGTN", 0);
   }

   public boolean clientRegistEnable() {
      return 1 == this.getGlobalSP().getInt("CLIENT_REGISTER_ENABLE", 0);
   }

   public int getQRLoginPriority() {
      return this.getGlobalSP().getInt("QR_CERT_FIRST", 0);
   }

   public int getOTPLength() {
      return this.getGlobalSP().getInt("OTP_LENGTH", 0);
   }

   public String getBaseDN() {
      return this.getGlobalSP().getString("BASE_DN", "");
   }

   <T> void writeCacheData(String key, T value) {
      this.cacheMap.put(key, value);
   }

   <T> T readCacheData(String key) {
      return this.cacheMap.get(key);
   }

   void cleanCache() {
      this.cacheMap.clear();
   }

   void initNative(@NonNull String deviceID) {
      IMSSdk.initializationNative(IMSSdk.mContext = this.context, deviceID);
   }

   public void initLogger() {
      IOException var10000;
      label57: {
         int var12;
         boolean var10001;
         try {
            IMSSdk.mLogger = Logger.getLogger("IMSSDK_LOG");
            var12 = VERSION.SDK_INT;
         } catch (IOException var9) {
            var10000 = var9;
            var10001 = false;
            break label57;
         }

         int var1 = var12;
         File var13;
         if (var12 >= 29) {
            try {
               var13 = this.context.getExternalFilesDir(Environment.DIRECTORY_DOWNLOADS);
            } catch (IOException var8) {
               var10000 = var8;
               var10001 = false;
               break label57;
            }
         } else if (var1 >= 23) {
            try {
               var12 = this.context.checkSelfPermission("android.permission.WRITE_EXTERNAL_STORAGE");
            } catch (IOException var7) {
               var10000 = var7;
               var10001 = false;
               break label57;
            }

            if (var12 == 0) {
               try {
                  var13 = Environment.getExternalStoragePublicDirectory(Environment.DIRECTORY_DOWNLOADS);
               } catch (IOException var6) {
                  var10000 = var6;
                  var10001 = false;
                  break label57;
               }
            } else {
               try {
                  var13 = this.context.getFilesDir();
               } catch (IOException var5) {
                  var10000 = var5;
                  var10001 = false;
                  break label57;
               }
            }
         } else {
            try {
               var13 = Environment.getExternalStoragePublicDirectory(Environment.DIRECTORY_DOWNLOADS);
            } catch (IOException var4) {
               var10000 = var4;
               var10001 = false;
               break label57;
            }
         }

         File var10 = var13;

         FileHandler var15;
         try {
            var15 = new FileHandler;
         } catch (IOException var3) {
            var10000 = var3;
            var10001 = false;
            break label57;
         }

         FileHandler var11;
         FileHandler var14 = var11 = var15;

         try {
            var14.<init>((new File(var10, "IMSSDK_LOG.txt")).getPath(), true);
            var15.setFormatter(new JSONFormatter());
            IMSSdk.mLogger.addHandler(var11);
            return;
         } catch (IOException var2) {
            var10000 = var2;
            var10001 = false;
         }
      }

      var10000.printStackTrace();
   }

   public Map<String, String> initOnLineBegin() {
      HashMap var1;
      HashMap var10000 = var1 = new HashMap;
      var10000.<init>();
      var10000.put("imei", Util.getIdentifier(IMSSdk.mContext));
      var10000.put("deviceName", Build.DEVICE);
      var10000.put("deviceVersion", "Android " + VERSION.RELEASE + " " + Build.MODEL);
      var10000.put("deviceType", "2");
      if (IMSSdk.isAppIndex) {
         var1.put("appType", "android");
         var1.put("appPack", IMSSdk.mContext.getPackageName());
         var1.put("s_appid", IMSSdk.appIDentifier);
      }

      return var1;
   }

   Result initOnLineFinal(JSONObject responseData) {
      JSONException var10000;
      label489: {
         boolean var10001;
         Result var92;
         try {
            var92 = this.checkResponseData(responseData);
         } catch (JSONException var87) {
            var10000 = var87;
            var10001 = false;
            break label489;
         }

         Result var2 = var92;
         String var93 = "000000";

         boolean var94;
         try {
            var94 = TextUtils.equals(var93, var2.getResultID());
         } catch (JSONException var86) {
            var10000 = var86;
            var10001 = false;
            break label489;
         }

         if (!var94) {
            return var2;
         }

         IMSAction var10002;
         JSONObject var10003;
         IMSAction var10004;
         JSONObject var10005;
         IMSAction var10006;
         JSONObject var10007;
         IMSAction var10008;
         JSONObject var10009;
         int var10010;
         IMSAction var95;
         JSONObject var96;
         try {
            var95 = this;
            var96 = responseData;
            var10002 = this;
            var10003 = responseData;
            var10004 = this;
            var10005 = responseData;
            var10006 = this;
            var10007 = responseData;
            var10008 = this;
            var10009 = responseData;
            var10010 = this.parseIntData(responseData.optString("A01"));
         } catch (JSONException var85) {
            var10000 = var85;
            var10001 = false;
            break label489;
         }

         int var90 = var10010;

         int var109;
         try {
            var109 = var10008.parseIntData(var10009.optString("A02"));
         } catch (JSONException var84) {
            var10000 = var84;
            var10001 = false;
            break label489;
         }

         int var3 = var109;

         int var106;
         try {
            var106 = var10006.parseIntData(var10007.optString("A03"));
         } catch (JSONException var83) {
            var10000 = var83;
            var10001 = false;
            break label489;
         }

         int var4 = var106;

         int var101;
         try {
            var101 = var10004.parseIntData(var10005.optString("A04"));
         } catch (JSONException var82) {
            var10000 = var82;
            var10001 = false;
            break label489;
         }

         int var5 = var101;

         String var97;
         try {
            var97 = var10002.parseStringData(var10003.optString("A05"));
         } catch (JSONException var81) {
            var10000 = var81;
            var10001 = false;
            break label489;
         }

         String var6 = var97;

         try {
            var93 = var95.parseStringData(var96.optString("A06"));
         } catch (JSONException var80) {
            var10000 = var80;
            var10001 = false;
            break label489;
         }

         String var7 = var93;

         try {
            var94 = "SM3withSM2".equals(var7);
         } catch (JSONException var79) {
            var10000 = var79;
            var10001 = false;
            break label489;
         }

         int var91;
         if (var94) {
            var91 = 256;
         } else {
            try {
               var94 = TextUtils.isEmpty(var7);
            } catch (JSONException var78) {
               var10000 = var78;
               var10001 = false;
               break label489;
            }

            if (var94) {
               var91 = 0;
            } else {
               int var105;
               try {
                  var105 = Integer.parseInt(var7);
               } catch (JSONException var77) {
                  var10000 = var77;
                  var10001 = false;
                  break label489;
               }

               var91 = var105;
            }
         }

         JSONObject var10011;
         IMSAction var10012;
         JSONObject var10013;
         IMSAction var10014;
         JSONObject var10015;
         IMSAction var10016;
         JSONObject var10017;
         IMSAction var10018;
         JSONObject var10019;
         IMSAction var10020;
         JSONObject var10021;
         IMSAction var10022;
         JSONObject var10023;
         IMSAction var10024;
         JSONObject var10025;
         IMSAction var10026;
         JSONObject var10027;
         IMSAction var10028;
         JSONObject var10029;
         IMSAction var10030;
         JSONObject var10031;
         IMSAction var10032;
         JSONObject var10033;
         int var10034;
         IMSAction var112;
         try {
            var95 = this;
            var96 = responseData;
            var10002 = this;
            var10003 = responseData;
            var10004 = this;
            var10005 = responseData;
            var10006 = this;
            var10007 = responseData;
            var10008 = this;
            var10009 = responseData;
            var112 = this;
            var10011 = responseData;
            var10012 = this;
            var10013 = responseData;
            var10014 = this;
            var10015 = responseData;
            var10016 = this;
            var10017 = responseData;
            var10018 = this;
            var10019 = responseData;
            var10020 = this;
            var10021 = responseData;
            var10022 = this;
            var10023 = responseData;
            var10024 = this;
            var10025 = responseData;
            var10026 = this;
            var10027 = responseData;
            var10028 = this;
            var10029 = responseData;
            var10030 = this;
            var10031 = responseData;
            var10032 = this;
            var10033 = responseData;
            var10034 = this.parseIntData(responseData.optString("A07"));
         } catch (JSONException var76) {
            var10000 = var76;
            var10001 = false;
            break label489;
         }

         int var8 = var10034;

         int var140;
         try {
            var140 = var10032.parseIntData(var10033.optString("A08"));
         } catch (JSONException var75) {
            var10000 = var75;
            var10001 = false;
            break label489;
         }

         int var9 = var140;

         int var139;
         try {
            var139 = var10030.parseIntData(var10031.optString("A10"));
         } catch (JSONException var74) {
            var10000 = var74;
            var10001 = false;
            break label489;
         }

         int var10 = var139;

         int var138;
         try {
            var138 = var10028.parseIntData(var10029.optString("A09"));
         } catch (JSONException var73) {
            var10000 = var73;
            var10001 = false;
            break label489;
         }

         int var11 = var138;

         int var137;
         try {
            var137 = var10026.parseIntData(var10027.optString("A14"));
         } catch (JSONException var72) {
            var10000 = var72;
            var10001 = false;
            break label489;
         }

         int var12 = var137;

         int var136;
         try {
            var136 = var10024.parseIntData(var10025.optString("A15"));
         } catch (JSONException var71) {
            var10000 = var71;
            var10001 = false;
            break label489;
         }

         int var13 = var136;

         int var133;
         try {
            var133 = var10022.parseIntData(var10023.optString("A11"));
         } catch (JSONException var70) {
            var10000 = var70;
            var10001 = false;
            break label489;
         }

         int var14 = var133;

         int var130;
         try {
            var130 = var10020.parseIntData(var10021.optString("A17"));
         } catch (JSONException var69) {
            var10000 = var69;
            var10001 = false;
            break label489;
         }

         int var15 = var130;

         long var127;
         try {
            var127 = var10018.parseLongData(var10019.optString("A16"));
         } catch (JSONException var68) {
            var10000 = var68;
            var10001 = false;
            break label489;
         }

         long var16 = var127;

         int var123;
         try {
            var123 = var10016.parseIntData(var10017.optString("A18"));
         } catch (JSONException var67) {
            var10000 = var67;
            var10001 = false;
            break label489;
         }

         int var18 = var123;

         int var119;
         try {
            var119 = var10014.parseIntData(var10015.optString("A12"));
         } catch (JSONException var66) {
            var10000 = var66;
            var10001 = false;
            break label489;
         }

         int var19 = var119;

         int var115;
         try {
            var115 = var10012.parseIntData(var10013.optString("A13"));
         } catch (JSONException var65) {
            var10000 = var65;
            var10001 = false;
            break label489;
         }

         int var20 = var115;

         try {
            var10010 = var112.parseIntData(var10011.optString("A19"));
         } catch (JSONException var64) {
            var10000 = var64;
            var10001 = false;
            break label489;
         }

         int var21 = var10010;

         try {
            var109 = var10008.parseIntData(var10009.optString("A20"));
         } catch (JSONException var63) {
            var10000 = var63;
            var10001 = false;
            break label489;
         }

         int var22 = var109;

         try {
            var106 = var10006.parseIntData(var10007.optString("A21"));
         } catch (JSONException var62) {
            var10000 = var62;
            var10001 = false;
            break label489;
         }

         int var23 = var106;

         String var102;
         try {
            var102 = var10004.parseStringData(var10005.optString("A23"));
         } catch (JSONException var61) {
            var10000 = var61;
            var10001 = false;
            break label489;
         }

         String var24 = var102;

         int var98;
         try {
            var98 = var10002.parseIntData(var10003.optString("A24"));
         } catch (JSONException var60) {
            var10000 = var60;
            var10001 = false;
            break label489;
         }

         int var25 = var98;

         try {
            var93 = var95.parseStringData(var96.optString("A25"));
         } catch (JSONException var59) {
            var10000 = var59;
            var10001 = false;
            break label489;
         }

         String var26 = var93;

         try {
            var94 = IMSSdk.isAppIndex;
         } catch (JSONException var58) {
            var10000 = var58;
            var10001 = false;
            break label489;
         }

         if (var94) {
            try {
               var94 = TextUtils.isEmpty(var26);
            } catch (JSONException var57) {
               var10000 = var57;
               var10001 = false;
               break label489;
            }

            if (!var94) {
               try {
                  IMSSdk.appIndex = var26;
               } catch (JSONException var56) {
                  var10000 = var56;
                  var10001 = false;
                  break label489;
               }
            }
         }

         try {
            var93 = this.parseStringData(responseData.optString("A26"));
         } catch (JSONException var55) {
            var10000 = var55;
            var10001 = false;
            break label489;
         }

         var26 = var93;

         try {
            var94 = TextUtils.isEmpty(var93);
         } catch (JSONException var54) {
            var10000 = var54;
            var10001 = false;
            break label489;
         }

         if (!var94) {
            try {
               IMSSdk.appSep = var26;
            } catch (JSONException var53) {
               var10000 = var53;
               var10001 = false;
               break label489;
            }
         }

         int var118;
         try {
            var95 = this;
            var118 = this.parseIntData(responseData.optString("A27"));
         } catch (JSONException var52) {
            var10000 = var52;
            var10001 = false;
            break label489;
         }

         int var88 = var118;

         SharedPreferences.Editor var99;
         SharedPreferences.Editor var100;
         SharedPreferences.Editor var103;
         SharedPreferences.Editor var104;
         SharedPreferences.Editor var107;
         SharedPreferences.Editor var108;
         SharedPreferences.Editor var110;
         SharedPreferences.Editor var111;
         SharedPreferences.Editor var113;
         SharedPreferences.Editor var114;
         SharedPreferences.Editor var116;
         SharedPreferences.Editor var117;
         SharedPreferences.Editor var120;
         SharedPreferences.Editor var121;
         SharedPreferences.Editor var122;
         SharedPreferences.Editor var124;
         SharedPreferences.Editor var125;
         SharedPreferences.Editor var126;
         SharedPreferences.Editor var128;
         SharedPreferences.Editor var129;
         SharedPreferences.Editor var131;
         SharedPreferences.Editor var132;
         SharedPreferences.Editor var134;
         SharedPreferences.Editor var135;
         try {
            var125 = var95.getGlobalSP().edit();
            var120 = var125;
            var99 = var125;
            var100 = var125;
            var103 = var125;
            var104 = var125;
            var107 = var125;
            var108 = var125;
            var110 = var125;
            var111 = var125;
            var113 = var125;
            var114 = var125;
            var116 = var125;
            var117 = var125;
            var121 = var125;
            var122 = var125;
            var124 = var125;
            var126 = var125;
            var128 = var125;
            var129 = var125;
            var131 = var125;
            var132 = var125;
            var134 = var125;
            var135 = var125;
            var125.putInt("IS_COLLABORATIVE", var14);
         } catch (JSONException var51) {
            var10000 = var51;
            var10001 = false;
            break label489;
         }

         try {
            var135.putInt("NETSEAL_IMAGE_SIZE", var15);
         } catch (JSONException var50) {
            var10000 = var50;
            var10001 = false;
            break label489;
         }

         try {
            var134.putLong("FILE_UPLOAD_PDF_SIZE", var16);
         } catch (JSONException var49) {
            var10000 = var49;
            var10001 = false;
            break label489;
         }

         try {
            var132.putInt("OS_MAX_PC_NUM", var13);
         } catch (JSONException var48) {
            var10000 = var48;
            var10001 = false;
            break label489;
         }

         try {
            var131.putInt("API_CHECK_TYPE", var12);
         } catch (JSONException var47) {
            var10000 = var47;
            var10001 = false;
            break label489;
         }

         try {
            var129.putInt("QR_CODE_EXPIRE_MILLSECONDS", var10);
         } catch (JSONException var46) {
            var10000 = var46;
            var10001 = false;
            break label489;
         }

         try {
            var128.putInt("SIGN_CODE_EXPIRE_MILLSECONDS", var9);
         } catch (JSONException var45) {
            var10000 = var45;
            var10001 = false;
            break label489;
         }

         try {
            var126.putInt("SIGN_CODE_LENGTH", var11);
         } catch (JSONException var44) {
            var10000 = var44;
            var10001 = false;
            break label489;
         }

         try {
            var124.putInt("APP_FORCE_UPDATE", var8);
         } catch (JSONException var43) {
            var10000 = var43;
            var10001 = false;
            break label489;
         }

         try {
            var122.putInt("CERT_KEY_LENGTN", var91);
         } catch (JSONException var42) {
            var10000 = var42;
            var10001 = false;
            break label489;
         }

         try {
            var121.putString("CERT_ALGORITHM", var6);
         } catch (JSONException var41) {
            var10000 = var41;
            var10001 = false;
            break label489;
         }

         try {
            var117.putInt("OTP_AVAILABLE", var5);
         } catch (JSONException var40) {
            var10000 = var40;
            var10001 = false;
            break label489;
         }

         try {
            var116.putInt("DIGITAL_SIGN_AVAILABLE", var4);
         } catch (JSONException var39) {
            var10000 = var39;
            var10001 = false;
            break label489;
         }

         try {
            var114.putInt("DIGITAL_CERT_AVAILABLE", var3);
         } catch (JSONException var38) {
            var10000 = var38;
            var10001 = false;
            break label489;
         }

         try {
            var113.putInt("PDF_AVAILABLE", var90);
         } catch (JSONException var37) {
            var10000 = var37;
            var10001 = false;
            break label489;
         }

         try {
            var111.putInt("IS_PAIRED_CERT", var18);
         } catch (JSONException var36) {
            var10000 = var36;
            var10001 = false;
            break label489;
         }

         try {
            var110.putInt("COLLABORATIVE_MODE", var19);
         } catch (JSONException var35) {
            var10000 = var35;
            var10001 = false;
            break label489;
         }

         try {
            var108.putInt("PDF_SIGN_MODE", var20);
         } catch (JSONException var34) {
            var10000 = var34;
            var10001 = false;
            break label489;
         }

         try {
            var107.putInt("CLIENT_REGISTER_ENABLE", var21);
         } catch (JSONException var33) {
            var10000 = var33;
            var10001 = false;
            break label489;
         }

         try {
            var104.putInt("GEN_P10_BY_SERVER", var22);
         } catch (JSONException var32) {
            var10000 = var32;
            var10001 = false;
            break label489;
         }

         try {
            var103.putInt("QR_CERT_FIRST", var23);
         } catch (JSONException var31) {
            var10000 = var31;
            var10001 = false;
            break label489;
         }

         try {
            var100.putString("BASE_DN", var24);
         } catch (JSONException var30) {
            var10000 = var30;
            var10001 = false;
            break label489;
         }

         try {
            var99.putInt("SIGN_WITH_TOKEN_MODE", var25);
         } catch (JSONException var29) {
            var10000 = var29;
            var10001 = false;
            break label489;
         }

         try {
            var120.putInt("OTP_LENGTH", var88);
         } catch (JSONException var28) {
            var10000 = var28;
            var10001 = false;
            break label489;
         }

         try {
            var125.apply();
            return new Result(responseData.getString("resultcode"));
         } catch (JSONException var27) {
            var10000 = var27;
            var10001 = false;
         }
      }

      JSONException var89 = var10000;
      var89.printStackTrace();
      IMSSdk.mLogger.log(Level.SEVERE, "在线初始化失败:JSON异常", var89);
      return new Result("IE1008", responseData.toString());
   }

   public Map<String, String> verifyAppIdBegin() {
      SecureRandom var3;
      var3 = new SecureRandom.<init>();
      byte[] var10000 = new byte[64];
      var3.nextBytes(var10000);
      String var4 = Base64.encodeToString(var10000, 2);
      HashMap var7 = new HashMap();
      var7.put("appId", IMSSdk.appIDentifier);
      var7.put("random", var4);
      var7.put("ori", "移动安全中间件主线3.0.13.2_Android_build20241217");
      byte[] var5 = (new SM3()).digest(IMSSdk.appSecretKey.concat(var4).getBytes());
      SM4 var1;
      SM4 var10002 = var1 = new SM4;
      byte[] var10003 = var5;
      byte[] var10004 = var5;
      byte[] var10005 = var5;
      var1.<init>();
      var5 = "移动安全中间件主线3.0.13.2_Android_build20241217".getBytes();
      byte[] var6 = Arrays.copyOf(var10005, 16);
      byte[] var2 = Arrays.copyOfRange(var10003, 16, var10004.length);
      var7.put("data", Base64.encodeToString(var10002.encryptCBC(var5, var6, var2), 2));
      return var7;
   }

   public Map<String, String> testAppIdBegin() {
      HashMap var10000 = new HashMap();
      var10000.put("imei", Util.getIdentifier(IMSSdk.mContext));
      return var10000;
   }

   protected Result commonFinal(JSONObject responseData) {
      try {
         return this.checkResponseData(responseData);
      } catch (JSONException var2) {
         var2.printStackTrace();
         IMSSdk.mLogger.log(Level.SEVERE, "操作失败:JSON异常", var2);
         return new Result("IE1008", responseData.toString());
      }
   }
}
